//******************************************************************************
//                  PIN MANAGER FILE FOR PIC16F1789                            *
//                  *******************************                            *
//   This file is used to set the port pins of the  PIC16F1789                 *
//                                                                             *
//******************************************************************************
//                                                                             *
//   Filename:      PIC16F1789_System_Manager.h                                *
//   Date:          Created on 21 June 2015, 7:33 PM                           *
//   File Version:  Ver 1.0                                                    *
//                                                                             *
//   Author:        Simon O'Farrell                                            *
//                                                                             *
//                                                                             *
//******************************************************************************
//                                                                             *
//   Files required:                                                           *
//                   <xc.h>                                                    *
//                   <stdint.h>                                                *
//                                                                             *
//                                                                             *
//******************************************************************************
//                                                                             *
//                                                                             *
//                               PIC16F1789 PINOUT                             *
//                               *****************                             *
//                                  __________                                 *
//                                 |          |                                *
//                 +5v ------!MCLR |1       40| RB7(PGD)-- (ICSP)              *
//    (ADC NTC MOSFET) ------I-RA0 |2       39| RB6(PGC)-- (ICSP)              *
//  (ADC CURRENT LOAD) ------|-RA1 |3       38| RB5-|----- (Unused)            *
//  (ADC VOLTAGE LOAD) ------|-RA2 |4       37| RB4-|----- (Unused)            *
//            (Unused) ------|-RA3 |5       36| RB3------I-ENCODER - (Current) *
//            (Unused) ------|-RA4 |6       35| RB2------I-ENCODER - (Current) *
//            (Unused) ------|-RA5 |7       34| RB1-O----- (Unused)            *
//            (Unused) ------|-RE0 |8       33| RB0/INT--  (ENC - SW)          *
//            (Unused) ------|-RE1 |9       32| VDD  ----- +5v                 *
//            (Unused) ------|-RE2 |10      31| VSS  ----- GND                 *
//                 +5v ------  VDD |11      30| RD7-O----- LCD_DB7(LCD pin 14) *
//                 GND ------  VSS |12      29| RD6-O----- LCD_DB6(LCD pin 13) *
//            (Unused) ------ OSC1 |13      28| RD5-O----- LCD_DB5(LCD pin 12) *
//            (Unused) ------ OSC2 |14      27| RD4-O----- LCD_DB4(LCD pin 11) *
//         (SPI Clock) ------  RC0 |15      26| RC7-|----- (Unused)            *
//          (SPI Data) ------|-RC1 |16      25| RC6-|----- (Unused)            *
//          (SPI SYNC) ------|-RC2 |17      24| RC5-|----- (Unused)            *
//            (Unused) ------|-RC3 |18      23| RC4-|----- (Unused)            *
//  LCD_rs (LCD pin 4) ------O-RD0 |19      22| RD3 |----- (Unused)            *
//  LCD_rw (LCD pin 5) ------O-RD1 |20      21| RD2-O----- LCD_e - (LCD pin 6) *
//                                 |__________|                                *
//                                                                             *
//******************************************************************************


#ifndef PIC16F1789_SYSTEM_MANAGER_H
#define	PIC16F1789_SYSTEM_MANAGER_H

#define _XTAL_FREQ  32000000            // oscillator frequency for _delay()

// --> G L O B A L  V A R I A B L E S   F O R
//     T H E   I N T E R U P T   V E C T O R <--
// This is the timer flag triggered from the interrupt vector.
extern int8_t pinState;

extern int8_t encoderDirection;

extern uint8_t timer0Flag;

extern uint8_t ADCFlag;

// --> G L O B A L   V A R I A B L E S   E N D  <--


// --> F U N C T I O N   P R O T O T Y P E S <--
// RUN ALL REQUIRED INITIALISATION ROUTINES HERE
void SYSTEM_Initialise(void);


// INITIALISE INTERNAL OSCILLATOR TO 32Mhz
void OSCILLATOR_Initialise(void);

// --> F U N C T I O N   P R O T O T Y P E S   E N D  <--
#endif	/* PIC16F1789_SYSTEM_MANAGER_H */

