
//******************************************************************************
//                    ROTARY ENCODER VOLT LIBRARY C FILE                       *
//                    **********************************                       *
//                                                                             *
//                    This library is used to process:                         *
//                    - inputs from an encoder NOT using interupts.            *
//                                                                             *
//******************************************************************************
//                                                                             *
//   Filename:      ROTARY_ENCODER_VOLT_FUNCTIONS.c                            *
//   Date:          01/03/2014                                                 *
//   File Version:  Ver 1.0                                                    *
//                                                                             *
//   Author:        Simon O'Farrell                                            *
//                                                                             *
//   Acknowledgements:                                                         *
//   *****************                                                         *
//   Really I used the PIC application notes and then wrote this.              *
//                                                                             *
//******************************************************************************
//                                                                             *
//   Files required:                                                           *
//                   <xc.h>                                                    *
//                   <stdint.h>                                                *
//                   <stdio.h>                                                 *
//                                                                             *
//                   HD44780_CUSTOM_CHARACTER.h                                *
//                   HD44780_HEADER.h                                          *
//                   ROTARY_ENCODER_VOLT_HEADER.h                              *
//                   POWER_SUPPLY_HEADER.h                                     *
//                   ../PIC16F877a_HARDWARE.h                                  *
//                                                                             *
//******************************************************************************
//                                                                             *
//                                ROTARY ENCODER                               *
//                                **************                               *
//                             BOURNS EM14A0D-B28-L049                         *
//                               OPTICAL ENCODER                               *
//                                                                             *
//                                    ** **                                    *
//                                 **       **------| ----  GROUND             *
//                                **    *    ** ----| ----  POWER - 5v         *
//                                **   ***   **                                *
//                                **    *    ** ----| ---- (RB2/RB4) PIN LEFT  *
//                                 **       **------| ---- (RB3/RB5) PIN RIGHT *
//                                    ** **                                    *
//       Note: RB2/RB3 Are the pins for adjusting the current for the dummy    *
//             load.                                                           *
//                                                                             *
//                                                                             *
//******************************************************************************

#include <xc.h>
#include <stdint.h>
#include <stdio.h>
#include <math.h>

#define _XTAL_FREQ  32000000

#include "ROTARY_ENCODER_FUNCTIONS.h"
#include "PIC16F1789_Pin_Manager.h"

#ifndef __bool_true_and_false_are_defined
#define __bool_true_and_false_are_defined

typedef unsigned char bool; 

#define true  1
#define false 0
#endif

// --> F U N C T I O N S <--
//     *****************
// --> Rotary Encoder Functions. <--

// --> R O T A R Y   E N C O D E R   I N I T I A L I S A T I O N  <--
void rotaryEncoderInitialisation()
{
    //Set up the encoder pins.
    ENCODER_TRIS_V_S = 0;              // Switch as input
    ENCODER_TRIS_1   = 1;              // Encoder pin 1 as output.
    ENCODER_TRIS_2   = 1;              // Encoder pin 2 as output.


    ANSELB = 0;                        // Set PORTB pins to digital output.
                                       //  ANSELB needs to be set to "0".

    // Next, set up PORTB RB2 and RB3 to trigger on rising edge as well as
    //   falling edge. This way when ever either one occurs the state table
    //   is consulted.
    //   REFER PAGE 163 of micro datasheet - INTERRUPT-ON-CHANGE.

    INTCONbits.IOCIE = 1;              // Enable interrupt-on-change flag.

    IOCBPbits.IOCBP2 = 1;              // Enable rising edge interrupt - RB2.

    IOCBPbits.IOCBP3 = 1;              // Enable rising edge interrupt - RB3.

    IOCBNbits.IOCBN2 = 1;              // Enable falling edge interrupt - RB2.

    IOCBNbits.IOCBN3 = 1;              // Enable falling edge interrupt - RB3.

    // Finally, setup the switch with weak pullups.

     OPTION_REGbits.nWPUEN = 0;       // Enable global pull ups

     WPUBbits.WPUB0 = 1;
}

// --> T E S T  I F   S W I T C H   I S   A C T U A L L Y   D O W N <--
bool voltSwitchIsDown()
{
    int deBounceCount;                  // debounce counter

    // --> Wait for button press, debounce by counting: <--
    for (deBounceCount = 0; deBounceCount <= 10; deBounceCount++)
    {
        __delay_ms(1);                  // Sample every 1 ms

        if (SWITCH == UP)          // If button up RB1 high)
        {
            return false;               // Restart count
        }
    }
    return true;
}


// --> T E S T  I F  S W I T C H   I S   N O W   U P <--
void voltSwitchIsUp()
{
    int deBounceCount;                  // debounce counter

    // --> Wait for VOLT button press, debounce by counting: <--
    for (deBounceCount = 0; deBounceCount <= 10; deBounceCount++)
    {
        __delay_ms(1);                  // Sample every 1 ms

        if (SWITCH == DOWN)        // If button up RB1 high)
        {
            deBounceCount = 0;          // Restart count
        }
    }
}

// --> F U N C T I O N S   E N D <--